AJS.SharePoint = AJS.SharePoint || {};

(function($) {
    /**
     * Given the list of SharePoint sites configured in Confluence (see {@link AJS.SharePoint#getSitesAsync}), returns the
     * site with the root URI that most closely matches the specified URI. If there is no site configured with even the
     * most vague of matches, _null_ is returned.
     *
     * @param   sites   The list of SharePoint sites configured in Confluence. May be retrieved by calling {@link AJS.SharePoint#getSitesAsync}
     * @param   uri     The fully-qualified, absolute URI to match
     *
     * @returns The site that is the closest match to the specified URI, or null if there is no match.
     */
    AJS.SharePoint.getClosestMatch = function(sites, uri) {
        var match = null;
        $.each(sites, function(index, site) {
            if (startsWith(site.serverUrl, uri)) {
                match = site;
                return false;
            }
        });
        return match;

        function startsWith(snippet, full) {
            return full.substring(0, snippet.length) === snippet;
        }
    };

    /**
     * Asynchronously retrieves the set of SharePoint sites configured in Confluence.
     *
     * @param   successHandler  Function to be invoked when the call succeeded. Method signature: function successHandler(sites).
     *                          For the format of the JSON object passed in to this method, see the com.atlassian.confluence.extra.sharepoint.actions.ConfiguredSitesAction.SiteSummary bean.
     * @param   errorHandler    Function to be invoked when the call to Confluence failed. Method signature is standard for a jQuery error handler (function errorHandler(jqXhr, textStatus, errorThrown)).
     */
    AJS.SharePoint.getSitesAsync = function (successHandler, errorHandler) {
        var requestSettings = {
            async: true,
            url: AJS.params.contextPath + "/plugins/sharepoint/configuredSites.action",
            dataType: "json",
            timeout: 30000, // 30 seconds.
            error: function(XMLHttpRequest, textStatus, errorThrown) {
                if (errorHandler && typeof errorHandler == "function")
                    errorHandler(XMLHttpRequest, textStatus, errorThrown);
            },
            success: function(data) {
                if (successHandler && typeof successHandler == "function")
                    successHandler(data);
            }
        };
        AJS.$.ajax(requestSettings);
    };
})(AJS.$);
